Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1AccessTuple

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

Information about the principal, resource, and permission to check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1AccessTuple

Returns a new instance of GoogleCloudPolicysimulatorV1AccessTuple.



435
436
437
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_resource_nameString

Required. The full resource name that identifies the resource. For example, // compute.googleapis.com/projects/my-project/zones/us-central1-a/instances/my- instance. For examples of full resource names for Google Cloud services, see https://cloud.google.com/iam/help/troubleshooter/full-resource-names. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


415
416
417
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 415

def full_resource_name
  @full_resource_name
end

#permissionString

Required. The IAM permission to check for the specified principal and resource. For a complete list of IAM permissions, see https://cloud.google.com/iam/help/ permissions/reference. For a complete list of predefined IAM roles and the permissions in each role, see https://cloud.google.com/iam/help/roles/ reference. Corresponds to the JSON property permission

Returns:

  • (String)


424
425
426
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 424

def permission
  @permission
end

#principalString

Required. The principal whose access you want to check, in the form of the email address that represents that principal. For example, alice@example.com or my-service-account@my-project.iam.gserviceaccount.com. The principal must be a Google Account or a service account. Other types of principals are not supported. Corresponds to the JSON property principal

Returns:

  • (String)


433
434
435
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 433

def principal
  @principal
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



440
441
442
443
444
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 440

def update!(**args)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @permission = args[:permission] if args.key?(:permission)
  @principal = args[:principal] if args.key?(:principal)
end