Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ExplainedAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

Details about how a set of policies, listed in ExplainedPolicy, resulted in a certain AccessState when replaying an access tuple.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ExplainedAccess

Returns a new instance of GoogleCloudPolicysimulatorV1ExplainedAccess.



589
590
591
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_stateString

Whether the principal in the access tuple has permission to access the resource in the access tuple under the given policies. Corresponds to the JSON property accessState

Returns:

  • (String)


573
574
575
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 573

def access_state
  @access_state
end

#errorsArray<Google::Apis::PolicysimulatorV1::GoogleRpcStatus>

If the AccessState is UNKNOWN, this field contains a list of errors explaining why the result is UNKNOWN. If the AccessState is GRANTED or NOT_GRANTED, this field is omitted. Corresponds to the JSON property errors



580
581
582
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 580

def errors
  @errors
end

#policiesArray<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ExplainedPolicy>

If the AccessState is UNKNOWN, this field contains the policies that led to that result. If the AccessState is GRANTED or NOT_GRANTED, this field is omitted. Corresponds to the JSON property policies



587
588
589
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 587

def policies
  @policies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



594
595
596
597
598
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 594

def update!(**args)
  @access_state = args[:access_state] if args.key?(:access_state)
  @errors = args[:errors] if args.key?(:errors)
  @policies = args[:policies] if args.key?(:policies)
end