Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb
Overview
ListOrgPolicyViolationsPreviewsResponse is the response message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolationsPreviews.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results.
-
#org_policy_violations_previews ⇒ Array<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview>
The list of OrgPolicyViolationsPreview Corresponds to the JSON property
orgPolicyViolationsPreviews.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse
Returns a new instance of GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsPreviewsResponse.
700 701 702 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results. If this field
is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
693 694 695 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 693 def next_page_token @next_page_token end |
#org_policy_violations_previews ⇒ Array<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview>
The list of OrgPolicyViolationsPreview
Corresponds to the JSON property orgPolicyViolationsPreviews
698 699 700 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 698 def org_policy_violations_previews @org_policy_violations_previews end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
705 706 707 708 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 705 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @org_policy_violations_previews = args[:org_policy_violations_previews] if args.key?(:org_policy_violations_previews) end |