Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb
Overview
ListOrgPolicyViolationsResponse is the response message for OrgPolicyViolationsPreviewService.ListOrgPolicyViolations
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results.
-
#org_policy_violations ⇒ Array<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolation>
The list of OrgPolicyViolations Corresponds to the JSON property
orgPolicyViolations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse
Returns a new instance of GoogleCloudPolicysimulatorV1ListOrgPolicyViolationsResponse.
727 728 729 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of results. If this field
is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
720 721 722 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 720 def next_page_token @next_page_token end |
#org_policy_violations ⇒ Array<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolation>
The list of OrgPolicyViolations
Corresponds to the JSON property orgPolicyViolations
725 726 727 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 725 def org_policy_violations @org_policy_violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
732 733 734 735 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 732 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @org_policy_violations = args[:org_policy_violations] if args.key?(:org_policy_violations) end |