Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ListReplayResultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ListReplayResultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb
Overview
Response message for Simulator.ListReplayResults.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that you can use to retrieve the next page of ReplayResult objects.
-
#replay_results ⇒ Array<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayResult>
The results of running a Replay.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ListReplayResultsResponse
constructor
A new instance of GoogleCloudPolicysimulatorV1ListReplayResultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ListReplayResultsResponse
Returns a new instance of GoogleCloudPolicysimulatorV1ListReplayResultsResponse.
753 754 755 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that you can use to retrieve the next page of ReplayResult objects. If
this field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
746 747 748 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 746 def next_page_token @next_page_token end |
#replay_results ⇒ Array<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayResult>
The results of running a Replay.
Corresponds to the JSON property replayResults
751 752 753 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 751 def replay_results @replay_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
758 759 760 761 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 758 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @replay_results = args[:replay_results] if args.key?(:replay_results) end |