Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyOverlayPolicyOverlay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

A change to an OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1OrgPolicyOverlayPolicyOverlay

Returns a new instance of GoogleCloudPolicysimulatorV1OrgPolicyOverlayPolicyOverlay.



843
844
845
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::PolicysimulatorV1::GoogleCloudOrgpolicyV2Policy

Defines an organization policy which is used to specify constraints for configurations of Google Cloud resources. Corresponds to the JSON property policy



835
836
837
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 835

def policy
  @policy
end

#policy_parentString

Optional. The parent of the policy we are attaching to. Example: "projects/ 123456" Corresponds to the JSON property policyParent

Returns:

  • (String)


841
842
843
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 841

def policy_parent
  @policy_parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



848
849
850
851
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 848

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
  @policy_parent = args[:policy_parent] if args.key?(:policy_parent)
end