Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

OrgPolicyViolationsPreview is a resource providing a preview of the violations that will exist if an OrgPolicy change is made. The list of violations are modeled as child resources and retrieved via a ListOrgPolicyViolations API call. There are potentially more OrgPolicyViolations than could fit in an embedded field. Thus, the use of a child resource instead of a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview

Returns a new instance of GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreview.



962
963
964
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this OrgPolicyViolationsPreview was created. Corresponds to the JSON property createTime

Returns:

  • (String)


914
915
916
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 914

def create_time
  @create_time
end

#custom_constraintsArray<String>

Output only. The names of the constraints against which all OrgPolicyViolations were evaluated. If OrgPolicyOverlay only contains PolicyOverlay then it contains the name of the configured custom constraint, applicable to the specified policies. Otherwise it contains the name of the constraint specified in CustomConstraintOverlay. Format: organizations/ organization_id/customConstraints/custom_constraint_id`Example: organizations/123/customConstraints/custom.createOnlyE2TypeVms Corresponds to the JSON propertycustomConstraints`

Returns:

  • (Array<String>)


925
926
927
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 925

def custom_constraints
  @custom_constraints
end

#nameString

Output only. The resource name of the OrgPolicyViolationsPreview. It has the following format: organizations/organization/locations/location/ orgPolicyViolationsPreviews/orgPolicyViolationsPreview`Example: organizations/my-example-org/locations/global/orgPolicyViolationsPreviews/ 506a5f7f Corresponds to the JSON propertyname`

Returns:

  • (String)


934
935
936
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 934

def name
  @name
end

#overlayGoogle::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyOverlay

The proposed changes to OrgPolicy. Corresponds to the JSON property overlay



939
940
941
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 939

def overlay
  @overlay
end

#resource_countsGoogle::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreviewResourceCounts

A summary of the state of all resources scanned for compliance with the changed OrgPolicy. Corresponds to the JSON property resourceCounts



945
946
947
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 945

def resource_counts
  @resource_counts
end

#stateString

Output only. The state of the OrgPolicyViolationsPreview. Corresponds to the JSON property state

Returns:

  • (String)


950
951
952
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 950

def state
  @state
end

#violations_countFixnum

Output only. The number of OrgPolicyViolations in this OrgPolicyViolationsPreview. This count may differ from resource_summary. noncompliant_count because each OrgPolicyViolation is specific to a resource * and* constraint. If there are multiple constraints being evaluated (i.e. multiple policies in the overlay), a single resource may violate multiple constraints. Corresponds to the JSON property violationsCount

Returns:

  • (Fixnum)


960
961
962
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 960

def violations_count
  @violations_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



967
968
969
970
971
972
973
974
975
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 967

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints)
  @name = args[:name] if args.key?(:name)
  @overlay = args[:overlay] if args.key?(:overlay)
  @resource_counts = args[:resource_counts] if args.key?(:resource_counts)
  @state = args[:state] if args.key?(:state)
  @violations_count = args[:violations_count] if args.key?(:violations_count)
end