Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreviewResourceCounts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

A summary of the state of all resources scanned for compliance with the changed OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreviewResourceCounts

Returns a new instance of GoogleCloudPolicysimulatorV1OrgPolicyViolationsPreviewResourceCounts.



1010
1011
1012
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compliantFixnum

Output only. Number of scanned resources with zero violations. Corresponds to the JSON property compliant

Returns:

  • (Fixnum)


986
987
988
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 986

def compliant
  @compliant
end

#errorsFixnum

Output only. Number of resources that returned an error when scanned. Corresponds to the JSON property errors

Returns:

  • (Fixnum)


991
992
993
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 991

def errors
  @errors
end

#noncompliantFixnum

Output only. Number of scanned resources with at least one violation. Corresponds to the JSON property noncompliant

Returns:

  • (Fixnum)


996
997
998
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 996

def noncompliant
  @noncompliant
end

#scannedFixnum

Output only. Number of resources checked for compliance. Must equal: unenforced + noncompliant + compliant + error Corresponds to the JSON property scanned

Returns:

  • (Fixnum)


1002
1003
1004
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1002

def scanned
  @scanned
end

#unenforcedFixnum

Output only. Number of resources where the constraint was not enforced, i.e. the Policy set enforced: false for that resource. Corresponds to the JSON property unenforced

Returns:

  • (Fixnum)


1008
1009
1010
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1008

def unenforced
  @unenforced
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1015
1016
1017
1018
1019
1020
1021
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1015

def update!(**args)
  @compliant = args[:compliant] if args.key?(:compliant)
  @errors = args[:errors] if args.key?(:errors)
  @noncompliant = args[:noncompliant] if args.key?(:noncompliant)
  @scanned = args[:scanned] if args.key?(:scanned)
  @unenforced = args[:unenforced] if args.key?(:unenforced)
end