Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayConfig
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb
Overview
The configuration used for a Replay.
Instance Attribute Summary collapse
-
#log_source ⇒ String
The logs to use as input for the Replay.
-
#policy_overlay ⇒ Hash<String,Google::Apis::PolicysimulatorV1::GoogleIamV1Policy>
A mapping of the resources that you want to simulate policies for and the policies that you want to simulate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ReplayConfig
constructor
A new instance of GoogleCloudPolicysimulatorV1ReplayConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ReplayConfig
Returns a new instance of GoogleCloudPolicysimulatorV1ReplayConfig.
1087 1088 1089 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#log_source ⇒ String
The logs to use as input for the Replay.
Corresponds to the JSON property logSource
1072 1073 1074 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1072 def log_source @log_source end |
#policy_overlay ⇒ Hash<String,Google::Apis::PolicysimulatorV1::GoogleIamV1Policy>
A mapping of the resources that you want to simulate policies for and the
policies that you want to simulate. Keys are the full resource names for the
resources. For example, //cloudresourcemanager.googleapis.com/projects/my-
project. For examples of full resource names for Google Cloud services, see
https://cloud.google.com/iam/help/troubleshooter/full-resource-names. Values
are Policy objects representing the policies that you want to simulate.
Replays automatically take into account any IAM policies inherited through the
resource hierarchy, and any policies set on descendant resources. You do not
need to include these policies in the policy overlay.
Corresponds to the JSON property policyOverlay
1085 1086 1087 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1085 def @policy_overlay end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1092 1093 1094 1095 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1092 def update!(**args) @log_source = args[:log_source] if args.key?(:log_source) @policy_overlay = args[:policy_overlay] if args.key?(:policy_overlay) end |