Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

The proposed changes to OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay.



1444
1445
1446
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_constraintsArray<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayCustomConstraintOverlay>

Optional. The OrgPolicy CustomConstraint changes to preview violations for. Any existing CustomConstraints with the same name will be overridden in the simulation. That is, violations will be determined as if all custom constraints in the overlay were instantiated. Only a single custom_constraint is supported in the overlay at a time. For evaluating multiple constraints, multiple GenerateOrgPolicyViolationsPreview requests are made, where each request evaluates a single constraint. Corresponds to the JSON property customConstraints



1434
1435
1436
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1434

def custom_constraints
  @custom_constraints
end

#policiesArray<Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay>

Optional. The OrgPolicy changes to preview violations for. Any existing OrgPolicies with the same name will be overridden in the simulation. That is, violations will be determined as if all policies in the overlay were created or updated. Corresponds to the JSON property policies



1442
1443
1444
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1442

def policies
  @policies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1449
1450
1451
1452
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1449

def update!(**args)
  @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints)
  @policies = args[:policies] if args.key?(:policies)
end