Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

A change to an OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyOverlayPolicyOverlay.



1500
1501
1502
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyGoogle::Apis::PolicysimulatorV1::GoogleCloudOrgpolicyV2Policy

Defines an organization policy which is used to specify constraints for configurations of Google Cloud resources. Corresponds to the JSON property policy



1492
1493
1494
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1492

def policy
  @policy
end

#policy_parentString

Optional. The parent of the policy we are attaching to. Example: "projects/ 123456" Corresponds to the JSON property policyParent

Returns:

  • (String)


1498
1499
1500
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1498

def policy_parent
  @policy_parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1505
1506
1507
1508
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1505

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
  @policy_parent = args[:policy_parent] if args.key?(:policy_parent)
end