Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

OrgPolicyViolationsPreview is a resource providing a preview of the violations that will exist if an OrgPolicy change is made. The list of violations are modeled as child resources and retrieved via a ListOrgPolicyViolations API call. There are potentially more OrgPolicyViolations than could fit in an embedded field. Thus, the use of a child resource instead of a field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreview.



1570
1571
1572
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when this OrgPolicyViolationsPreview was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1522
1523
1524
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1522

def create_time
  @create_time
end

#custom_constraintsArray<String>

Output only. The names of the constraints against which all OrgPolicyViolations were evaluated. If OrgPolicyOverlay only contains PolicyOverlay then it contains the name of the configured custom constraint, applicable to the specified policies. Otherwise it contains the name of the constraint specified in CustomConstraintOverlay. Format: organizations/ organization_id/customConstraints/custom_constraint_id`Example: organizations/123/customConstraints/custom.createOnlyE2TypeVms Corresponds to the JSON propertycustomConstraints`

Returns:

  • (Array<String>)


1533
1534
1535
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1533

def custom_constraints
  @custom_constraints
end

#nameString

Output only. The resource name of the OrgPolicyViolationsPreview. It has the following format: organizations/organization/locations/location/ orgPolicyViolationsPreviews/orgPolicyViolationsPreview`Example: organizations/my-example-org/locations/global/orgPolicyViolationsPreviews/ 506a5f7f Corresponds to the JSON propertyname`

Returns:

  • (String)


1542
1543
1544
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1542

def name
  @name
end

#overlayGoogle::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyOverlay

The proposed changes to OrgPolicy. Corresponds to the JSON property overlay



1547
1548
1549
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1547

def overlay
  @overlay
end

#resource_countsGoogle::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts

A summary of the state of all resources scanned for compliance with the changed OrgPolicy. Corresponds to the JSON property resourceCounts



1553
1554
1555
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1553

def resource_counts
  @resource_counts
end

#stateString

Output only. The state of the OrgPolicyViolationsPreview. Corresponds to the JSON property state

Returns:

  • (String)


1558
1559
1560
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1558

def state
  @state
end

#violations_countFixnum

Output only. The number of OrgPolicyViolations in this OrgPolicyViolationsPreview. This count may differ from resource_summary. noncompliant_count because each OrgPolicyViolation is specific to a resource * and* constraint. If there are multiple constraints being evaluated (i.e. multiple policies in the overlay), a single resource may violate multiple constraints. Corresponds to the JSON property violationsCount

Returns:

  • (Fixnum)


1568
1569
1570
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1568

def violations_count
  @violations_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1575
1576
1577
1578
1579
1580
1581
1582
1583
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1575

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_constraints = args[:custom_constraints] if args.key?(:custom_constraints)
  @name = args[:name] if args.key?(:name)
  @overlay = args[:overlay] if args.key?(:overlay)
  @resource_counts = args[:resource_counts] if args.key?(:resource_counts)
  @state = args[:state] if args.key?(:state)
  @violations_count = args[:violations_count] if args.key?(:violations_count)
end