Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb

Overview

A summary of the state of all resources scanned for compliance with the changed OrgPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts

Returns a new instance of GoogleCloudPolicysimulatorV1betaOrgPolicyViolationsPreviewResourceCounts.



1618
1619
1620
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compliantFixnum

Output only. Number of scanned resources with zero violations. Corresponds to the JSON property compliant

Returns:

  • (Fixnum)


1594
1595
1596
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1594

def compliant
  @compliant
end

#errorsFixnum

Output only. Number of resources that returned an error when scanned. Corresponds to the JSON property errors

Returns:

  • (Fixnum)


1599
1600
1601
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1599

def errors
  @errors
end

#noncompliantFixnum

Output only. Number of scanned resources with at least one violation. Corresponds to the JSON property noncompliant

Returns:

  • (Fixnum)


1604
1605
1606
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1604

def noncompliant
  @noncompliant
end

#scannedFixnum

Output only. Number of resources checked for compliance. Must equal: unenforced + noncompliant + compliant + error Corresponds to the JSON property scanned

Returns:

  • (Fixnum)


1610
1611
1612
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1610

def scanned
  @scanned
end

#unenforcedFixnum

Output only. Number of resources where the constraint was not enforced, i.e. the Policy set enforced: false for that resource. Corresponds to the JSON property unenforced

Returns:

  • (Fixnum)


1616
1617
1618
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1616

def unenforced
  @unenforced
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1623
1624
1625
1626
1627
1628
1629
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1623

def update!(**args)
  @compliant = args[:compliant] if args.key?(:compliant)
  @errors = args[:errors] if args.key?(:errors)
  @noncompliant = args[:noncompliant] if args.key?(:noncompliant)
  @scanned = args[:scanned] if args.key?(:scanned)
  @unenforced = args[:unenforced] if args.key?(:unenforced)
end