Class: Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayResult
- Inherits:
-
Object
- Object
- Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/policysimulator_v1/classes.rb,
lib/google/apis/policysimulator_v1/representations.rb,
lib/google/apis/policysimulator_v1/representations.rb
Overview
The result of replaying a single access tuple against a simulated state.
Instance Attribute Summary collapse
-
#access_tuple ⇒ Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1AccessTuple
Information about the principal, resource, and permission to check.
-
#diff ⇒ Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayDiff
The difference between the results of evaluating an access tuple under the current (baseline) policies and under the proposed (simulated) policies.
-
#error ⇒ Google::Apis::PolicysimulatorV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#last_seen_date ⇒ Google::Apis::PolicysimulatorV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#name ⇒ String
The resource name of the
ReplayResult, in the following format:projects| folders|organizations`/`resource-id`/locations/global/replays/`replay-id`/ results/`replay-result-id, whereresource-idis the ID of the project, folder, or organization that owns the Replay. -
#parent ⇒ String
The Replay that the access tuple was included in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ReplayResult
constructor
A new instance of GoogleCloudPolicysimulatorV1ReplayResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudPolicysimulatorV1ReplayResult
Returns a new instance of GoogleCloudPolicysimulatorV1ReplayResult.
1194 1195 1196 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_tuple ⇒ Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1AccessTuple
Information about the principal, resource, and permission to check.
Corresponds to the JSON property accessTuple
1147 1148 1149 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1147 def access_tuple @access_tuple end |
#diff ⇒ Google::Apis::PolicysimulatorV1::GoogleCloudPolicysimulatorV1ReplayDiff
The difference between the results of evaluating an access tuple under the
current (baseline) policies and under the proposed (simulated) policies. This
difference explains how a principal's access could change if the proposed
policies were applied.
Corresponds to the JSON property diff
1155 1156 1157 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1155 def diff @diff end |
#error ⇒ Google::Apis::PolicysimulatorV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1165 1166 1167 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1165 def error @error end |
#last_seen_date ⇒ Google::Apis::PolicysimulatorV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property lastSeenDate
1177 1178 1179 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1177 def last_seen_date @last_seen_date end |
#name ⇒ String
The resource name of the ReplayResult, in the following format: projects|
folders|organizations`/`resource-id`/locations/global/replays/`replay-id`/
results/`replay-result-id, where resource-id is the ID of the project,
folder, or organization that owns the Replay. Example: projects/my-example-
project/locations/global/replays/506a5f7f-38ce-4d7d-8e03-479ce1833c36/results/
1234
Corresponds to the JSON property name
1187 1188 1189 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1187 def name @name end |
#parent ⇒ String
The Replay that the access tuple was included in.
Corresponds to the JSON property parent
1192 1193 1194 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1192 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1199 1200 1201 1202 1203 1204 1205 1206 |
# File 'lib/google/apis/policysimulator_v1/classes.rb', line 1199 def update!(**args) @access_tuple = args[:access_tuple] if args.key?(:access_tuple) @diff = args[:diff] if args.key?(:diff) @error = args[:error] if args.key?(:error) @last_seen_date = args[:last_seen_date] if args.key?(:last_seen_date) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) end |